# Description

We refer users to the article for all the details about the experimental design, experimental stimuli and software used to collect responses.

File is in a comma separated values (CSV) format, with the first row being a header row with names of the variables. There are no missing values in the whole dataset. The data was minimally processed - only variables that could potentially be used to identify the participants was removed. 

The dataset contains 60 variables with 15600 observations in total. These are results of 78 individuals, 200 obervations per individual. The variables in the dataset are described in more details in the code sheet section below. 


## Code sheet

Description consists of three elements each separated by a hyphen, first being the exact name of the variable used in the dataset header, second element is a brief description of the variable while the third element is type of the variable.


1. **subjectID** - unique identifier of a participant in the experiment - integer  
2. **psychopyVersion** - version of Psychopy libraries used for running the experiment - string  
3. **expCond** - experimental condition - string  
4. **consent** - participant has signed the consent form or not - string  
5. **gender** - gender of the participant, values: male, female - string    
6. **age** - age of the participant in years - numeric, integer  
7. **major** - participants major at the university, values: Economics & Business, Engineering, Humanities, Law, Other - string  
8. **itemID** - identifier of the trial item, same for all individuals, as tehy have received identical stimuli - numeric, integer  
9. **feat1label** - label of feature 1 as it was shown on the screen, topmost feature, values: "Acético", "Caseina", "Láctico", "Textura" - string  
10. **feat2label** - label of feature 2 as it was shown on the screen, second topmost feature, values: "Acético", "Caseina", "Láctico", "Textura" - string  
11. **feat3label**  - label of feature 3 as it was shown on the screen, third topmost feature, values: "Acético", "Caseina", "Láctico", "Textura" - string  
12. **feat4label** - label of feature 4 as it was shown on the screen, fourth toppmost feature, values: "Acético", "Caseina", "Láctico", "Textura" - string  
13. **obj1no** - identifier of the item presented on the leftmost position on the screen - numeric, integer  
14. **obj1feat1** - value of first cue of the item presented on the leftmost position of the screen - numeric, integer   
15. **obj1feat2** - value of second cue of the item presented on the leftmost position of the screen - numeric, integer   
16. **obj1feat3** - value of third cue of the item presented on the leftmost position of the screen - numeric, integer     
17. **obj1feat4** - value of fourth cue of the item presented on the leftmost position of the screen - numeric, integer  
18. **obj1val** - value of the criterion of the item presented on the leftmost position of the screen - numeric, float  
19. **obj2no** - identifier of the item presented in the middle on the screen - numeric, integer  
20. **obj2feat1** - value of first cue of the item presented in the middle on the screen - numeric, integer   
21. **obj2feat2** - value of second cue of the item presented in the middle on the screen - numeric, integer   
22. **obj2feat3** - value of third cue of the item presented in the middle on the screen - numeric, integer      
23. **obj2feat4** - value of fourth cue of the item presented in the middle on the screen - numeric, integer  
24. **obj2val** - value of the criterion of the item presented in the middle on the screen - numeric, float  
25. **obj3no** - identifier of the item presented on the rightmost position on the screen - numeric, integer  
26. **obj3feat1** - value of first cue of the item presented on the rightmost position on the screen - numeric, integer   
27. **obj3feat2** - value of second cue of the item presented on the rightmost position on the screen - numeric, integer   
28. **obj3feat3** - value of third cue of the item presented on the rightmost position on the screen - numeric, integer      
29. **obj3feat4** - value of fourth cue of the item presented on the rightmost position on the screen - numeric, integer  
30. **obj3val** - value of the criterion of the item presented on the rightmost position on the screen - numeric, float  
31. **feedbackID** - indicator whether feedback was given in this trial, values: 0 = No, 1 = Yes - numeric, integer  
32. **randfeat1** - how feature 1 was randomized for this participant, values: 1, 2, 3 or 4 - numeric, integer  
33. **randfeat2** - how feature 2 was randomized for this participant, values: 1, 2, 3 or 4 - numeric, integer  
34. **randfeat3** - how feature 3 was randomized for this participant, values: 1, 2, 3 or 4 - numeric, integer  
35. **randfeat4** - how feature 4 was randomized for this participant, values: 1, 2, 3 or 4 - numeric, integer  
36. **randAlt1** - how position of alternative 1 was randomized for this participant, values: 1, 2 or 3 - numeric, integer  
37. **randAlt2** - how position of alternative 2 was randomized for this participant, values: 1, 2 or 3 - numeric, integer  
38. **randAlt3** - how position of alternative 3 was randomized for this participant, values: 1, 2 or 3 - numeric, integer  
39. **phase** - phase of the experiment, either training phase where people do a decision making task and receive feedback on their performance (value "training"), or test phase where people do an estimation task and do not receive feedback (value "test") - string  
40. **trial** - the trial number the participant is in, there is a separate count for training phase and for the test phase - numeric, integer  
41. **choice** - object number of the alternative the participant has chosen in the trial, comes from **obj1no**, **obj2no** or **obj3no** - numeric, integer    
42. **funValue**  - value of the chosen alternative, also shown as feedback to the participants - numeric, integer  
43. **timeChoice** - time duration in seconds from presentation of the stimuli until the participant clicked the button for choosing one of the two presented alternatives - numeric, float  
44. **pred1** - participant's prediction of the value of alternative 1, shown leftmost on the screen, in the test phase there is no choice and **pred1** is the response recorded, value: NA if prediction was not asked, integer value if asked  - numeric, integer
45. **pred2** - participant's prediction of the value of alternative 2, shown leftmost on the screen, value: NA if prediction was not asked, integer value if asked  - numeric, integer
46. **pred3** - participant's prediction of the value of alternative 3, shown leftmost on the screen, value: NA if prediction was not asked, integer value if asked  - numeric, integer
47. **timePred1** - time taken to make a prediction for alternative 1, value: NA if prediction was not asked, time duration in seconds if asked, from choice until prediction or from presentation of the stimuli until prediction in test phase case - numeric, float  
48. **timePred2** - time taken to make a prediction for alternative 2, value: NA if prediction was not asked, time duration in seconds if asked, from choice until prediction - numeric, float  
49. **timePred3** - time taken to make a prediction for alternative 3, value: NA if prediction was not asked, time duration in seconds if asked, from choice until prediction - numeric, float  
50. **timeTrial** - time duration of the current trial in seconds, from presentation of the stimuli until the participant clicked the button to continue to the next trial - numeric, float  
51. **totalEarning** - total number of experimental points earned up to that point - numeric, integer  
52. **timeTotal** - total time spent in the experiment up to that point - numeric, float  
53. **insFeat1** - survey question asked every 40 trials in the test phase about importance of the feature 1, on scale from -10 (very negative) to 10 (very positive) - numeric, float  
54. **insFeat2** - survey question asked every 40 trials in the test phase about importance of the feature 2, on scale from -10 (very negative) to 10 (very positive) - numeric, float  
55. **insFeat3** - survey question asked every 40 trials in the test phase about importance of the feature 3, on scale from -10 (very negative) to 10 (very positive) - numeric, float  
56. **insFeat4** - survey question asked every 40 trials in the test phase about importance of the feature 4, on scale from -10 (very negative) to 10 (very positive) - numeric, float  
57. **insRtFeat1** - time taken to give a rating for feature 1, in seconds - numeric, float  
58. **insRtFeat2** - time taken to give a rating for feature 2, in seconds - numeric, float  
59. **insRtFeat3** - time taken to give a rating for feature 3, in seconds - numeric, float  
60. **insRtFeat4** - time taken to give a rating for feature 4, in seconds - numeric, float  
